@@ -46,15 +46,15 @@ struct _PangoCairoATSUIFontClass
 
 
 
-static cairo_font_face_t *pango_cairo_atsui_font_create_font_face           (PangoCairoFont *font);
-static PangoFontMetrics  *pango_cairo_atsui_font_create_metrics_for_context (PangoCairoFont *font,
-                                                                            PangoContext    *context);
+static cairo_font_face_t *pango_cairo_atsui_font_create_font_face                (PangoCairoFont *font);
+static PangoFontMetrics  *pango_cairo_atsui_font_create_base_metrics_for_context (PangoCairoFont *font,
+										  PangoContext    *context);
 
 static void
 cairo_font_iface_init (PangoCairoFontIface *iface)
 {
   iface->create_font_face = pango_cairo_atsui_font_create_font_face;
-  iface->create_metrics_for_context = pango_cairo_atsui_font_create_metrics_for_context;
+  iface->create_base_metrics_for_context = pango_cairo_atsui_font_create_base_metrics_for_context;
   iface->cf_priv_offset = G_STRUCT_OFFSET (PangoCairoATSUIFont, cf_priv);
 }
 
@@ -113,19 +113,14 @@ max_glyph_width (PangoLayout *layout)
 }
 
 static PangoFontMetrics *
-pango_cairo_atsui_font_create_metrics_for_context (PangoCairoFont *font,
-                                                   PangoContext   *context)
+pango_cairo_atsui_font_create_base_metrics_for_context (PangoCairoFont *font,
+							PangoContext   *context)
 {
   PangoCairoATSUIFont *cafont = (PangoCairoATSUIFont *) font;
   PangoATSUIFont *afont = (PangoATSUIFont *) font;
   ATSFontRef ats_font;
   ATSFontMetrics ats_metrics;
   PangoFontMetrics *metrics;
-  PangoFontDescription *font_desc;
-  PangoLayout *layout;
-  PangoRectangle extents;
-  PangoLanguage *language = pango_context_get_language (context);
-  const char *sample_str = pango_language_get_sample_string (language);
 
   metrics = pango_font_metrics_new ();
 
@@ -141,20 +136,6 @@ pango_cairo_atsui_font_create_metrics_for_context (PangoCairoFont *font,
   metrics->strikethrough_position = metrics->ascent / 3;
   metrics->strikethrough_thickness = ats_metrics.underlineThickness * cafont->size * PANGO_SCALE;
 
-  layout = pango_layout_new (context);
-  font_desc = pango_font_describe_with_absolute_size ((PangoFont *) font);
-  pango_layout_set_font_description (layout, font_desc);
-  pango_layout_set_text (layout, sample_str, -1);
-  pango_layout_get_extents (layout, NULL, &extents);
-
-  metrics->approximate_char_width = extents.width / pango_utf8_strwidth (sample_str);
-
-  pango_layout_set_text (layout, "0123456789", -1);
-  metrics->approximate_digit_width = max_glyph_width (layout);
-
-  pango_font_description_free (font_desc);
-  g_object_unref (layout);
-
   return metrics;
 }
 
